@@ -5,6 +5,7 @@ from __future__ import annotations
 import typing
 from abc import ABC, abstractmethod
 
+from dbt_score.config import Config
 from dbt_score.scoring import Score
 
 if typing.TYPE_CHECKING:
@@ -15,9 +16,10 @@ from dbt_score.models import ManifestLoader, Model
 class Formatter(ABC):
     """Abstract class to define a formatter."""
 
-    def __init__(self, manifest_loader: ManifestLoader):
+    def __init__(self, manifest_loader: ManifestLoader, config: Config):
         """Instantiate a formatter."""
         self._manifest_loader = manifest_loader
+        self._config = config
 
     @abstractmethod
     def model_evaluated(
