@@ -7,6 +7,7 @@ from dbt_score.config import Config
 from dbt_score.evaluation import Evaluation
 from dbt_score.formatters.ascii_formatter import ASCIIFormatter
 from dbt_score.formatters.human_readable_formatter import HumanReadableFormatter
+from dbt_score.formatters.json_formatter import JSONFormatter
 from dbt_score.formatters.manifest_formatter import ManifestFormatter
 from dbt_score.models import ManifestLoader
 from dbt_score.rule_registry import RuleRegistry
@@ -18,7 +19,7 @@ def lint_dbt_project(
     config: Config,
     format: Literal["plain", "manifest", "ascii"],
     select: Iterable[str] | None = None,
-) -> None:
+) -> Evaluation:
     """Lint dbt manifest."""
     if not manifest_path.exists():
         raise FileNotFoundError(f"Manifest not found at {manifest_path}.")
@@ -32,8 +33,9 @@ def lint_dbt_project(
         "plain": HumanReadableFormatter,
         "manifest": ManifestFormatter,
         "ascii": ASCIIFormatter,
+        "json": JSONFormatter,
     }
-    formatter = formatters[format](manifest_loader=manifest_loader)
+    formatter = formatters[format](manifest_loader=manifest_loader, config=config)
 
     scorer = Scorer(config)
 
@@ -44,3 +46,5 @@ def lint_dbt_project(
         scorer=scorer,
     )
     evaluation.evaluate()
+
+    return evaluation
