@@ -1,14 +1,15 @@
 """Unit tests for the ASCII formatter."""
 
-from typing import Type
 
+from dbt_score.evaluation import ModelResultsType
 from dbt_score.formatters.ascii_formatter import ASCIIFormatter
-from dbt_score.rule import Rule, RuleViolation
+from dbt_score.rule import RuleViolation
 from dbt_score.scoring import Score
 
 
 def test_ascii_formatter_model(
     capsys,
+    default_config,
     manifest_loader,
     model1,
     rule_severity_low,
@@ -16,8 +17,8 @@ def test_ascii_formatter_model(
     rule_severity_critical,
 ):
     """Ensure the formatter doesn't write anything after model evaluation."""
-    formatter = ASCIIFormatter(manifest_loader=manifest_loader)
-    results: dict[Type[Rule], RuleViolation | Exception | None] = {
+    formatter = ASCIIFormatter(manifest_loader=manifest_loader, config=default_config)
+    results: ModelResultsType = {
         rule_severity_low: None,
         rule_severity_medium: Exception("Oh noes"),
         rule_severity_critical: RuleViolation("Error"),
@@ -27,9 +28,9 @@ def test_ascii_formatter_model(
     assert stdout == ""
 
 
-def test_ascii_formatter_project(capsys, manifest_loader):
+def test_ascii_formatter_project(capsys, default_config, manifest_loader):
     """Ensure the formatter has the correct output after project evaluation."""
-    formatter = ASCIIFormatter(manifest_loader=manifest_loader)
+    formatter = ASCIIFormatter(manifest_loader=manifest_loader, config=default_config)
 
     formatter.project_evaluated(Score(10.0, "🥇"))
     stdout_gold = capsys.readouterr().out
